@@ -7,9 +7,12 @@ sub new {
     my $class = shift();
     my($setname, $cql) = @_;
 
+    my $barcode = _extract_barcode($cql);
+
     return bless {
 	setname => $setname,
 	cql => $cql,
+	barcode => $barcode,
 	total_count => undef,
 	records => [],
 	marcRecords => {},
@@ -25,6 +28,11 @@ sub total_count {
     return $old;
 }
 
+sub barcode {
+    my $this = shift();
+    return $this->{barcode};
+}
+
 sub insert_records {
     my $this = shift();
     my($offset, $records) = @_;
@@ -60,4 +68,20 @@ sub marcRecord {
     return $mr->{$instanceId};
 }
 
+
+# If the $cql query is a search for a barcode, return that barcode;
+# otherwise return undefined. We could do this the sophisticated way,
+# by parsing the CQL and examing every node, but in practice it
+# probably suffices to do a simple string check.
+#
+sub _extract_barcode {
+    my ($cql) = @_;
+
+    if ($cql =~ /^item.barcode[\t ]*=[\t ]*(.*)/) {
+	return $1;
+    }
+
+    return undef;
+}
+
 1;
